@@ -24,7 +24,7 @@
 activate <- function(project = NULL) {
   renv_consent_check()
   renv_scope_error_handler()
-  project <- project %||% renv_project()
+  project <- renv_project_resolve(project)
   renv_activate_impl(project, NULL, FALSE, FALSE)
   invisible(project)
 }
