@@ -28,6 +28,11 @@ renv_project <- function(default = getwd()) {
   project
 }
 
+renv_project_resolve <- function(project = NULL) {
+  project <- project %||% renv_project()
+  normalizePath(project, winslash = "/", mustWork = FALSE)
+}
+
 renv_project_initialized <- function(project) {
 
   lockfile <- renv_lockfile_path(project)
@@ -143,7 +148,9 @@ renv_project_ignored_packages <- function(project) {
   # for R package projects, ensure the project itself is ignored
   if (renv_project_type(project) == "package") {
     desc <- renv_description_read(project)
-    ignored <- c(ignored, desc[["Package"]])
+    package <- desc[["Package"]]
+    if (!identical(package, "renv"))
+      ignored <- c(ignored, desc[["Package"]])
   }
 
   # return collected set of ignored packages
