@@ -221,7 +221,7 @@ renv_settings_impl <- function(name, validate, default, update) {
   )
 
   function(value, project = NULL, persist = TRUE) {
-    project <- project %||% renv_project()
+    project <- renv_project_resolve(project)
     if (missing(value))
       renv_settings_get(project, name)
     else
@@ -241,14 +241,6 @@ renv_settings_impl <- function(name, validate, default, update) {
 #'
 #' \describe{
 #'
-#' \item{\code{ignored.packages}}{
-#'
-#'   A vector of packages, which should be ignored when attempting to snapshot
-#'   the project's private library. Note that if a package has already been
-#'   added to the lockfile, that entry in the lockfile will not be ignored. \cr
-#'
-#' }
-#'
 #' \item{\code{external.libraries}}{
 #'
 #'   A vector of library paths, to be used in addition to the project's own
@@ -260,6 +252,25 @@ renv_settings_impl <- function(name, validate, default, update) {
 #'
 #' }
 #'
+#' \item{\code{ignored.packages}}{
+#'
+#'   A vector of packages, which should be ignored when attempting to snapshot
+#'   the project's private library. Note that if a package has already been
+#'   added to the lockfile, that entry in the lockfile will not be ignored.
+#'
+#' }
+#'
+#' \item{\code{package.dependency.fields}}{
+#'
+#'   During dependency discovery, `renv` uses the fields of an installed
+#'   package's `DESCRIPTION` file to determine that package's recursive
+#'   dependencies. By default, the `Imports`, `Depends` and `LinkingTo` fields
+#'   are used. If you'd prefer that `renv` also captures the `Suggests`
+#'   dependencies for a package, you can set this to
+#'   `c("Imports", "Depends", "LinkingTo", "Suggests")`.
+#'
+#' }
+#'
 #' \item{\code{snapshot.type}}{
 #'
 #'   The type of snapshot to perform by default. See [snapshot] for more
@@ -330,6 +341,13 @@ settings <- list(
     update   = NULL
   ),
 
+  package.dependency.fields = renv_settings_impl(
+    name     = "package.dependency.fields",
+    validate = is.character,
+    default  = c("Imports", "Depends", "LinkingTo"),
+    update   = NULL
+  ),
+
   snapshot.type = renv_settings_impl(
     name     = "snapshot.type",
     validate = function(x) x %in% c("custom", "simple", "packrat"),
