@@ -5,7 +5,7 @@ renv_tempfile <- function(pattern = "renv-",
 {
   path <- tempfile(pattern, tmpdir, fileext)
   norm <- renv_file_normalize(path, winslash = "/")
-  defer(unlink(norm, recursive = TRUE), envir = parent.frame())
+  defer(unlink(norm, recursive = TRUE, force = TRUE), envir = parent.frame())
   norm
 }
 
